==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/nb-NO/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Denne brukeren kan logge inn',
    'activated_disabled_help_text' => 'Du kan ikke redigere aktiveringsstatus for din egen konto.',
    'assets_user'       => 'Eiendeler tildelt :name',
    'bulk_update_warn'	=> 'Du prøver å redigere egenskapene for: user_count brukere. Merk at du kan ikke endre dine egne brukerens attributter ved hjelp av dette skjemaet, og må gjøre endringer i din egen bruker individuelt.',
    'bulk_update_help'	=> 'I dette skjemaet kan du oppdatere flere brukere samtidig. Bare fyll ut feltene du vil endre. Eventuelle tomme felt vil forbli uendret.',
    'current_assets'    => 'Eiendeler som er sjekket ut til denne brukeren',
    'clone'             => 'Klon bruker',
    'contact_user'      => 'Kontakt :navn',
    'edit'              => 'Rediger bruker',
    'filetype_info'     => 'Gyldige filtyper er png, gif, jpg, jpeg, doc docx, pdf, txt, zip og rar.',
    'history_user'      => 'Historikk for :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klikk her for å gjenopprette dem.',
    'last_login'        => 'Siste innlogging',
    'ldap_config_text'  => 'LDAP-konfigurasjonsinnstillingene kan finnes på Admin > innstillinger. Den (Valgfrie) valgte plasseringen angis for alle importerte brukere.',
    'print_assigned'    => 'Skriv ut alt tilordnet',
    'email_assigned'    => 'Epostliste for alle tilknyttede',
    'user_notified'     => 'Brukeren har blitt sendt en liste over elementer som er tildelt brukeren.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Inkluder denne brukeren ved automatisk tildeling av kvalifiserte lisenser',
    'auto_assign_help'  => 'Hopp over brukeren i autotildeling av lisenser',
    'software_user'     => 'Programvare utsjekket til :name',
    'send_email_help'   => 'Du må legge inn brukerens e-postadresse for å kunne sende dem innloggingsinformasjon. Sending av innloggingsinformasjon kan kun gjøres når brukeren blir opprettet. Passordet lagres på en sikker måte, slik at det ikke kan hentes opp når det er lagret.',
    'view_user'         => 'Vis bruker :name',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Gjeldende administrasjonsinnstillinger tillater selektiv håndhevelse av to-faktor autentisering.  ',
    'two_factor_enrolled' => '2FA enhet registrert ',
    'two_factor_active'   => '2FA Aktiv ',
    'user_deactivated'  => 'Bruker kan ikke logge inn',
    'user_activated'  => 'Bruker kan logge inn',
    'activation_status_warning' => 'Ikke endre aktiveringsstatus',
    'group_memberships_helpblock' => 'Bare superbrukere kan redigere gruppemedlemskap.',
    'superadmin_permission_warning' => 'Kun superbrukere kan gjøre en annen bruker til superbruker.',
    'admin_permission_warning' => 'Kun brukere med adminrettigheter eller høyere kan gi en annen bruker admintilgang.',
    'remove_group_memberships' => 'Fjern gruppemedlemskap',
    'warning_deletion_information' => 'Du er i ferd med å sjekke inn ALLE elementene fra :count bruker(e) nedenfor. Super admin navn er uthevet med rødt.',
    'update_user_assets_status' => 'Oppdater alle ressursene til disse brukerne til denne statusen',
    'checkin_user_properties' => 'Sjekk inn alt tilbehør koblet til disse brukerne',
    'remote_label'   => 'Dette er en ekstern bruker',
    'remote'   => 'Ekstern',
    'remote_help' => 'Dette kan være nyttig hvis du trenger å filtrere ut eksterne brukere som aldri eller sjelden kommer inn i dine fysiske steder.',
    'not_remote_label' => 'Dette er ikke en ekstern bruker',
    'vip_label' => 'VIP bruker',
    'vip_help' => 'Dette kan være nyttig for å markere viktige mennesker i org hvis du vil håndtere dem på spesielle måter.',
    'create_user' => 'Opprett en bruker',
    'create_user_page_explanation' => 'Dette er kontoinformasjon du vil bruke for å få tilgang til nettstedet for første gang.',
    'email_credentials' => 'E-post påloggingsinformasjon',
    'email_credentials_text' => 'Send opplysningene mine til e-postadressen ovenfor',
    'next_save_user' => 'Neste: Lagre bruker',
    'all_assigned_list_generation' => 'Generert på:',
    'email_user_creds_on_create' => 'Send denne brukeren sin påloggingsinformasjon via e-post?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/nb-NO/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Denne brukeren kan logge inn',
    'activated_disabled_help_text' => 'Du kan ikke redigere aktiveringsstatus for din egen konto.',
    'assets_user'       => 'Eiendeler tildelt :name',
    'bulk_update_warn'	=> 'Du prøver å redigere egenskapene for: user_count brukere. Merk at du kan ikke endre dine egne brukerens attributter ved hjelp av dette skjemaet, og må gjøre endringer i din egen bruker individuelt.',
    'bulk_update_help'	=> 'I dette skjemaet kan du oppdatere flere brukere samtidig. Bare fyll ut feltene du vil endre. Eventuelle tomme felt vil forbli uendret.',
    'current_assets'    => 'Eiendeler som er sjekket ut til denne brukeren',
    'clone'             => 'Klon bruker',
    'contact_user'      => 'Kontakt :navn',
    'edit'              => 'Rediger bruker',
    'filetype_info'     => 'Gyldige filtyper er png, gif, jpg, jpeg, doc docx, pdf, txt, zip og rar.',
    'history_user'      => 'Historikk for :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klikk her for å gjenopprette dem.',
    'last_login'        => 'Siste innlogging',
    'ldap_config_text'  => 'LDAP-konfigurasjonsinnstillingene kan finnes på Admin > innstillinger. Den (Valgfrie) valgte plasseringen angis for alle importerte brukere.',
    'print_assigned'    => 'Skriv ut alt tilordnet',
    'email_assigned'    => 'Epostliste for alle tilknyttede',
    'user_notified'     => 'Brukeren har blitt sendt en liste over elementer som er tildelt brukeren.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Inkluder denne brukeren ved automatisk tildeling av kvalifiserte lisenser',
    'auto_assign_help'  => 'Hopp over brukeren i autotildeling av lisenser',
    'software_user'     => 'Programvare utsjekket til :name',
    'view_user'         => 'Vis bruker :name',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Gjeldende administrasjonsinnstillinger tillater selektiv håndhevelse av to-faktor autentisering.  ',
    'two_factor_enrolled' => '2FA enhet registrert ',
    'two_factor_active'   => '2FA Aktiv ',
    'user_deactivated'  => 'Bruker kan ikke logge inn',
    'user_activated'  => 'Bruker kan logge inn',
    'activation_status_warning' => 'Ikke endre aktiveringsstatus',
    'group_memberships_helpblock' => 'Bare superbrukere kan redigere gruppemedlemskap.',
    'superadmin_permission_warning' => 'Kun superbrukere kan gjøre en annen bruker til superbruker.',
    'admin_permission_warning' => 'Kun brukere med adminrettigheter eller høyere kan gi en annen bruker admintilgang.',
    'remove_group_memberships' => 'Fjern gruppemedlemskap',
    'warning_deletion_information' => 'Du er i ferd med å sjekke inn ALLE elementene fra :count bruker(e) nedenfor. Super admin navn er uthevet med rødt.',
    'update_user_assets_status' => 'Oppdater alle ressursene til disse brukerne til denne statusen',
    'checkin_user_properties' => 'Sjekk inn alt tilbehør koblet til disse brukerne',
    'remote_label'   => 'Dette er en ekstern bruker',
    'remote'   => 'Ekstern',
    'remote_help' => 'Dette kan være nyttig hvis du trenger å filtrere ut eksterne brukere som aldri eller sjelden kommer inn i dine fysiske steder.',
    'not_remote_label' => 'Dette er ikke en ekstern bruker',
    'vip_label' => 'VIP bruker',
    'vip_help' => 'Dette kan være nyttig for å markere viktige mennesker i org hvis du vil håndtere dem på spesielle måter.',
    'create_user' => 'Opprett en bruker',
    'create_user_page_explanation' => 'Dette er kontoinformasjon du vil bruke for å få tilgang til nettstedet for første gang.',
    'email_credentials' => 'E-post påloggingsinformasjon',
    'email_credentials_text' => 'Send opplysningene mine til e-postadressen ovenfor',
    'next_save_user' => 'Neste: Lagre bruker',
    'all_assigned_list_generation' => 'Generert på:',
    'email_user_creds_on_create' => 'Send denne brukeren sin påloggingsinformasjon via e-post?',
    'department_manager' => 'Avdeling leder',
];
